import _plotly_utils.basevalidators


class SpikemodeValidator(_plotly_utils.basevalidators.FlaglistValidator):
    def __init__(self, plotly_name="spikemode", parent_name="layout.xaxis", **kwargs):
        super(SpikemodeValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type=kwargs.pop("edit_type", "none"),
            flags=kwargs.pop("flags", ["toaxis", "across", "marker"]),
            **kwargs,
        )



import _plotly_utils.basevalidators


class OutlinecolorValidator(_plotly_utils.basevalidators.ColorValidator):
    def __init__(
        self,
        plotly_name="outlinecolor",
        parent_name="scatter3d.marker.colorbar",
        **kwargs,
    ):
        super(OutlinecolorValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type=kwargs.pop("edit_type", "calc"),
            **kwargs,
        )



"""
offline
======
This module provides offline functionality.
"""
from .offline import (
    download_plotlyjs,
    get_plotlyjs_version,
    get_plotlyjs,
    enable_mpl_offline,
    init_notebook_mode,
    iplot,
    iplot_mpl,
    plot,
    plot_mpl,
)



def _jupyter_labextension_paths():
    return [{"src": "labextension", "dest": "jupyterlab-plotly"}]


def _jupyter_nbextension_paths():
    return [
        {
            "section": "notebook",
            "src": "nbextension",
            "dest": "jupyterlab-plotly",
            "require": "jupyterlab-plotly/extension",
        }
    ]



import _plotly_utils.basevalidators


class SceneValidator(_plotly_utils.basevalidators.SubplotidValidator):
    def __init__(self, plotly_name="scene", parent_name="volume", **kwargs):
        super(SceneValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            dflt=kwargs.pop("dflt", "scene"),
            edit_type=kwargs.pop("edit_type", "calc+clearAxisTypes"),
            **kwargs,
        )



import plotly.validators


class LayoutValidator(plotly.validators.LayoutValidator):
    def __init__(self, plotly_name="layout", parent_name="frame", **kwargs):
        super(LayoutValidator, self).__init__(
            plotly_name=plotly_name, parent_name=parent_name, **kwargs
        )



import _plotly_utils.basevalidators


class TypeValidator(_plotly_utils.basevalidators.EnumeratedValidator):
    def __init__(self, plotly_name="type", parent_name="layout.updatemenu", **kwargs):
        super(TypeValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type=kwargs.pop("edit_type", "arraydraw"),
            values=kwargs.pop("values", ["dropdown", "buttons"]),
            **kwargs,
        )
